database_kohel: Database of modular and Hilbert polynomials
===========================================================

Description
-----------

Database of modular and Hilbert polynomials.


Upstream Contact
----------------

-  David Kohel <David.Kohel@univ-amu.fr>
